@@ -1,8 +1,8 @@
 //===========================================================================
 // @(#) $Name$
-// @(#) $Id: DwmFileLogger.cc 8388 2016-04-17 03:23:45Z dwm $
+// @(#) $Id: DwmFileLogger.cc 10180 2018-08-31 04:00:39Z dwm $
 //===========================================================================
-//  Copyright (c) Daniel W. McRobb 2007,2015
+//  Copyright (c) Daniel W. McRobb 2007,2015,2016,2018
 //  All rights reserved.
 //
 //  Redistribution and use in source and binary forms, with or without
@@ -54,24 +54,53 @@ extern "C" {
 #include "DwmFileLogger.hh"
 #include "DwmPathUtils.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.6.13/src/DwmFileLogger.cc 8388 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.6.16/src/DwmFileLogger.cc 10180 $");
 
 using namespace std;
 
 namespace Dwm {
+
+  //--------------------------------------------------------------------------
+  //!  
+  //--------------------------------------------------------------------------
+  const map<int,string>  FileLogger::_defaultPriorityTags = {
+    { LOG_EMERG,   "[M]" },
+    { LOG_ALERT,   "[A]" },
+    { LOG_CRIT,    "[C]" },
+    { LOG_ERR,     "[E]" },
+    { LOG_WARNING, "[W]" },
+    { LOG_NOTICE,  "[N]" },
+    { LOG_INFO,    "[I]" },
+    { LOG_DEBUG,   "[D]" }
+  };
+
+  //--------------------------------------------------------------------------
+  //!  
+  //--------------------------------------------------------------------------
+  const map<string,int>  FileLogger::_defaultPriorityNames = {
+    { "debug",     LOG_DEBUG   },
+    { "info",      LOG_INFO    },
+    { "notice",    LOG_NOTICE  },
+    { "warning",   LOG_WARNING },
+    { "error",     LOG_ERR     },
+    { "critical",  LOG_CRIT    },
+    { "alert",     LOG_ALERT   },
+    { "emergency", LOG_EMERG   }
+  };
   
   //------------------------------------------------------------------------
   //!  
   //------------------------------------------------------------------------
   FileLogger::FileLogger()
-      : _isOpen(false), _logOptions(0), _minimumPriority(LOG_DEBUG),
-        _ident(), _showPriorities(false), _showFunction(false), 
+      : _logOptions(0), _minimumPriority(LOG_DEBUG), _ident(),
+        _showPriorities(false), _showFunction(false),
         _showFileLocation(false), _hostName(), _filePrefix(), _file(0),
         _rolloverSize(k_defaultRolloverSize), 
         _numRolloverFiles(k_defaultNumRolloverFiles),
-        _currentFilePosition(0), _bufferingType(e_notBuffered),
-        _priorityTags(), _priorityNames(), _mutex()
+        _currentFilePosition(0), _bufferingType(e_notBuffered), _mutex()
   {
+    _priorityTags = _defaultPriorityTags;
+    _priorityNames = _defaultPriorityNames;
   }
 
   //------------------------------------------------------------------------
@@ -107,11 +136,9 @@ namespace Dwm {
                         const string & filename,
                         BufferingType bufferingType)
   {
-    this->Lock();
+    lock_guard<mutex>  lock(_mutex);
     InitializePriorities();
-    bool  rc = this->OpenNoLock(ident, logopt, filename, bufferingType);
-    this->Unlock();
-    return(rc);
+    return this->OpenNoLock(ident, logopt, filename, bufferingType);
   }
   
   //------------------------------------------------------------------------
@@ -139,7 +166,7 @@ namespace Dwm {
       return(rc);
     }
 
-    if (_isOpen) {
+    if (_file) {
       //  we're already open; close first
       if (! CloseNoLock()) {
         //  failed to close
@@ -179,25 +206,31 @@ namespace Dwm {
   bool FileLogger::OpenFile(const string & filename)
   {
     bool  rc = false;
-    _file = fopen(filename.c_str(),"w");
+    _file = fopen(filename.c_str(), "a+");
     if (_file) {
       rc = true;
-      _isOpen = true;
-      _currentFilePosition = 0;
+      _currentFilePosition = ftell(_file);
     }
 
     return(rc);
   }
-    
+
+  //--------------------------------------------------------------------------
+  //!  
+  //--------------------------------------------------------------------------
+  std::string FileLogger::FilePrefix() const
+  {
+    lock_guard<mutex>  lock(_mutex);
+    return _filePrefix;
+  }
+  
   //------------------------------------------------------------------------
   //!  
   //------------------------------------------------------------------------
   bool FileLogger::IsOpen() const
   {
-    Lock();
-    bool  rc = _isOpen;
-    Unlock();
-    return(rc);
+    lock_guard<mutex>  lock(_mutex);
+    return(0 != _file);
   }
 
   //------------------------------------------------------------------------
@@ -205,10 +238,8 @@ namespace Dwm {
   //------------------------------------------------------------------------
   bool FileLogger::Close()
   {
-    Lock();
-    bool  rc = CloseNoLock();
-    Unlock();
-    return(rc);
+    lock_guard<mutex>  lock(_mutex);
+    return CloseNoLock();
   }
   
   //------------------------------------------------------------------------
@@ -218,16 +249,12 @@ namespace Dwm {
   {
     bool  rc = false;
 
-    if ((! _isOpen) || (! _file))
+    if (! _file)
       return(rc);
     
     if (fclose(_file) == 0) {
       rc = true;
       _file = (FILE *)0;
-    }
-
-    if (rc) {
-      _isOpen = false;
       _ident = "";
       _logOptions = 0;
     }
@@ -288,16 +315,14 @@ namespace Dwm {
   {
     bool  rc = false;
 
-    Lock();
+    lock_guard<mutex>  lock(_mutex);
     
-    if (! _isOpen) {
-      Unlock();
-      return(rc);
+    if (! _file) {
+      return rc;
     }
 
     if (priority > _minimumPriority) {
-      Unlock();
-      return(true);
+      return true;
     }
 
     static const char *monthNames[] = { "Jan", "Feb", "Mar", "Apr",
@@ -345,9 +370,7 @@ namespace Dwm {
       }
     }
 
-    Unlock();
-    
-    return(rc);
+    return rc;
   }
 
   //------------------------------------------------------------------------
@@ -357,16 +380,14 @@ namespace Dwm {
   {
     bool  rc = false;
 
-    Lock();
-    if (_isOpen && _file) {
+    lock_guard<mutex>  lock(_mutex);
+    if (_file) {
       if (fflush(_file) == 0) {
         rc = true;
       }
     }
-
-    Unlock();
     
-    return(rc);
+    return rc;
   }
   
   //------------------------------------------------------------------------
@@ -374,10 +395,8 @@ namespace Dwm {
   //------------------------------------------------------------------------
   int FileLogger::MinimumPriority() const
   {
-    Lock();
-    int  rc = _minimumPriority;
-    Unlock();
-    return(rc);
+    lock_guard<mutex>  lock(_mutex);
+    return _minimumPriority;
   }
   
   //------------------------------------------------------------------------
@@ -385,10 +404,9 @@ namespace Dwm {
   //------------------------------------------------------------------------
   int FileLogger::MinimumPriority(int minimumPriority)
   {
-    Lock();
+    lock_guard<mutex>  lock(_mutex);
     _minimumPriority = minimumPriority;
-    Unlock();
-    return(minimumPriority);
+    return _minimumPriority;
   }
   
   //------------------------------------------------------------------------
@@ -396,10 +414,8 @@ namespace Dwm {
   //------------------------------------------------------------------------
   bool FileLogger::ShowPriorities() const
   {
-    Lock();
-    bool  rc = _showPriorities;
-    Unlock();
-    return(rc);
+    lock_guard<mutex>  lock(_mutex);
+    return _showPriorities;
   }
 
   //------------------------------------------------------------------------
@@ -407,10 +423,9 @@ namespace Dwm {
   //------------------------------------------------------------------------
   bool FileLogger::ShowPriorities(bool showPriorities)
   {
-    Lock();
+    lock_guard<mutex>  lock(_mutex);
     _showPriorities = showPriorities;
-    Unlock();
-    return(showPriorities);
+    return _showPriorities;
   }
 
   //------------------------------------------------------------------------
@@ -418,10 +433,8 @@ namespace Dwm {
   //------------------------------------------------------------------------
   bool FileLogger::ShowFunction() const
   {
-    Lock();
-    bool  rc = _showFunction;
-    Unlock();
-    return(rc);
+    lock_guard<mutex>  lock(_mutex);
+    return _showFunction;
   }
 
   //------------------------------------------------------------------------
@@ -429,10 +442,9 @@ namespace Dwm {
   //------------------------------------------------------------------------
   bool FileLogger::ShowFunction(bool showFunction)
   {
-    Lock();
+    lock_guard<mutex>  lock(_mutex);
     _showFunction = showFunction;
-    Unlock();
-    return(showFunction);
+    return _showFunction;
   }
 
   //------------------------------------------------------------------------
@@ -440,10 +452,8 @@ namespace Dwm {
   //------------------------------------------------------------------------
   bool FileLogger::ShowFileLocation() const
   {
-    Lock();
-    bool  rc = _showFileLocation;
-    Unlock();
-    return(rc);
+    lock_guard<mutex>  lock(_mutex);
+    return _showFileLocation;
   }
 
   //------------------------------------------------------------------------
@@ -451,10 +461,9 @@ namespace Dwm {
   //------------------------------------------------------------------------
   bool FileLogger::ShowFileLocation(bool showFileLocation)
   {
-    Lock();
+    lock_guard<mutex>  lock(_mutex);
     _showFileLocation = showFileLocation;
-    Unlock();
-    return(showFileLocation);
+    return _showFileLocation;
   }
 
   //------------------------------------------------------------------------
@@ -462,10 +471,8 @@ namespace Dwm {
   //------------------------------------------------------------------------
   uint32_t FileLogger::RolloverSize() const
   {
-    Lock();
-    uint32_t  rc = _rolloverSize;
-    Unlock();
-    return(rc);
+    lock_guard<mutex>  lock(_mutex);
+    return _rolloverSize;
   }
 
   //------------------------------------------------------------------------
@@ -473,10 +480,9 @@ namespace Dwm {
   //------------------------------------------------------------------------
   uint32_t FileLogger::RolloverSize(uint32_t rolloverSize)
   {
-    Lock();
+    lock_guard<mutex>  lock(_mutex);
     _rolloverSize = rolloverSize;
-    Unlock();
-    return(rolloverSize);
+    return _rolloverSize;
   }
 
   //------------------------------------------------------------------------
@@ -484,10 +490,8 @@ namespace Dwm {
   //------------------------------------------------------------------------
   uint32_t FileLogger::NumRolloverFiles() const
   {
-    Lock();
-    uint32_t  rc = _numRolloverFiles;
-    Unlock();
-    return(rc);
+    lock_guard<mutex>  lock(_mutex);
+    return _numRolloverFiles;
   }
 
   //------------------------------------------------------------------------
@@ -495,10 +499,9 @@ namespace Dwm {
   //------------------------------------------------------------------------
   uint32_t FileLogger::NumRolloverFiles(uint32_t numRolloverFiles)
   {
-    Lock();
+    lock_guard<mutex>  lock(_mutex);
     _numRolloverFiles = numRolloverFiles;
-    Unlock();
-    return(numRolloverFiles);
+    return _numRolloverFiles;
   }
 
   //------------------------------------------------------------------------
@@ -511,7 +514,7 @@ namespace Dwm {
     string   filePrefix = _filePrefix;
     BufferingType  bufferingType = _bufferingType;
     
-    if (_isOpen) {
+    if (_file) {
       if (! CloseNoLock())
         return(false);
     }
@@ -521,14 +524,14 @@ namespace Dwm {
     string       srcFile, dstFile;
     struct stat  statbuf;
     
-    for (uint32_t i = _numRolloverFiles; i > 1; --i) {
+    for (uint32_t i = _numRolloverFiles; i >= 1; --i) {
       memset(buf,0,16);
-      snprintf(buf,sizeof(buf),"%u",i - 1);
+      snprintf(buf, sizeof(buf), "%u", i - 1);
       srcFile = filePrefix + "." + buf;
       if (stat(srcFile.c_str(),&statbuf) == 0) {
         //  srcFile exists.
         memset(buf,0,16);
-        snprintf(buf,sizeof(buf),"%u",i);
+        snprintf(buf, sizeof(buf), "%u", i);
         dstFile = filePrefix + "." + buf;
         if (rename(srcFile.c_str(),dstFile.c_str()) != 0) {
           rc = false;
@@ -561,17 +564,15 @@ namespace Dwm {
   SetPriorities(const map<int,pair<string,string> > & priorities)
   {
     bool  rc = false;
-    if (Lock()) {
-      _priorityTags.clear();
-      _priorityNames.clear();
-      map<int, pair<string,string> >::const_iterator  i;
-      for (auto & i : priorities) {
-        _priorityTags[i.first] = i.second.first;
-        _priorityNames[i.second.second] = i.first;
-      }
-      Unlock();
-      rc = true;
+    lock_guard<mutex>  lock(_mutex);
+    _priorityTags.clear();
+    _priorityNames.clear();
+    map<int, pair<string,string> >::const_iterator  i;
+    for (auto & i : priorities) {
+      _priorityTags[i.first] = i.second.first;
+      _priorityNames[i.second.second] = i.first;
     }
+    rc = true;
     return(rc);
   }
   
@@ -580,41 +581,19 @@ namespace Dwm {
   //--------------------------------------------------------------------------
   std::string FileLogger::PriorityTag(int priority)
   {
-    string  rc("");
+    string  rc;
     auto  i = _priorityTags.find(priority);
     if (i != _priorityTags.end()) {
       rc = i->second;
     }
     return(rc);
   }
-    
+
   //--------------------------------------------------------------------------
   //!  
   //--------------------------------------------------------------------------
   void FileLogger::InitializePriorities()
   {
-    if (_priorityTags.empty()) {
-      _priorityTags[LOG_EMERG]   = "[M]";
-      _priorityTags[LOG_ALERT]   = "[A]";
-      _priorityTags[LOG_CRIT]    = "[C]";
-      _priorityTags[LOG_ERR]     = "[E]";
-      _priorityTags[LOG_WARNING] = "[W]";
-      _priorityTags[LOG_NOTICE]  = "[N]";
-      _priorityTags[LOG_INFO]    = "[I]";
-      _priorityTags[LOG_DEBUG]   = "[D]";
-    }
-    
-    if (_priorityNames.empty()) {
-      _priorityNames["debug"]     = LOG_DEBUG;
-      _priorityNames["info"]      = LOG_INFO;
-      _priorityNames["notice"]    = LOG_NOTICE;
-      _priorityNames["warning"]   = LOG_WARNING;
-      _priorityNames["error"]     = LOG_ERR;
-      _priorityNames["critical"]  = LOG_CRIT;
-      _priorityNames["alert"]     = LOG_ALERT;
-      _priorityNames["emergency"] = LOG_EMERG;
-    }
-
     return;
   }
   
