@@ -1,6 +1,6 @@
 //===========================================================================
 // @(#) $Name$
-// @(#) $Id: DwmProcessInfo.cc 9018 2017-04-11 20:05:43Z dwm $
+// @(#) $Id: DwmProcessInfo.cc 10621 2020-05-02 21:51:49Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2006-2007
 //  All rights reserved.
@@ -60,10 +60,12 @@ extern "C" {
 #include "DwmProcessInfo.hh"
 #include "DwmProcessTable.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.6.13/src/DwmProcessInfo.cc 9018 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.6.16/src/DwmProcessInfo.cc 10621 $");
 
 namespace Dwm {
 
+  using namespace std;
+  
   //--------------------------------------------------------------------------
   //!  
   //--------------------------------------------------------------------------
@@ -257,7 +259,7 @@ namespace Dwm {
   //--------------------------------------------------------------------------
   //!  
   //--------------------------------------------------------------------------
-  const std::string & ProcessInfo::ControllingTty() const
+  const string & ProcessInfo::ControllingTty() const
   {
     return(_controllingTty);
   }
@@ -273,7 +275,7 @@ namespace Dwm {
   //--------------------------------------------------------------------------
   //!  
   //--------------------------------------------------------------------------
-  std::string ProcessInfo::EffectiveUserName() const
+  string ProcessInfo::EffectiveUserName() const
   {
     Password  passwd(_effectiveUserId);
     return(passwd.UserName());
@@ -290,7 +292,7 @@ namespace Dwm {
   //--------------------------------------------------------------------------
   //!  
   //--------------------------------------------------------------------------
-  std::string ProcessInfo::RealUserName() const
+  string ProcessInfo::RealUserName() const
   {
     Password  passwd(_realUserId);
     return(passwd.UserName());
@@ -307,7 +309,7 @@ namespace Dwm {
   //--------------------------------------------------------------------------
   //!  
   //--------------------------------------------------------------------------
-  std::string ProcessInfo::SavedEffectiveUserName() const
+  string ProcessInfo::SavedEffectiveUserName() const
   {
     Password  passwd(_savedEffectiveUserId);
     return(passwd.UserName());
@@ -332,7 +334,7 @@ namespace Dwm {
   //--------------------------------------------------------------------------
   //!  
   //--------------------------------------------------------------------------
-  const std::string & ProcessInfo::Command() const
+  const string & ProcessInfo::Command() const
   { 
     return(_command);
   }
@@ -340,7 +342,7 @@ namespace Dwm {
   //--------------------------------------------------------------------------
   //!  
   //--------------------------------------------------------------------------
-  const std::vector<std::string> & ProcessInfo::Args() const
+  const vector<string> & ProcessInfo::Args() const
   {
     return(_args);
   }
@@ -400,7 +402,7 @@ namespace Dwm {
   //--------------------------------------------------------------------------
   //!  
   //--------------------------------------------------------------------------
-  std::istream & ProcessInfo::Read(std::istream & is)
+  istream & ProcessInfo::Read(istream & is)
   {
     if (is) {
       int32_t  val32;
@@ -473,7 +475,7 @@ namespace Dwm {
   //--------------------------------------------------------------------------
   //!  
   //--------------------------------------------------------------------------
-  std::ostream & ProcessInfo::Write(std::ostream & os) const
+  ostream & ProcessInfo::Write(ostream & os) const
   {
     if (os) {
       int32_t  val32 = _id;
@@ -651,7 +653,7 @@ namespace Dwm {
     return(rc);
 
   readError:
-    std::cerr << "Read(gzf) failed for ProcessInfo" << std::endl;
+    cerr << "Read(gzf) failed for ProcessInfo" << endl;
     return(-1);
   }
   
@@ -770,7 +772,7 @@ namespace Dwm {
   //--------------------------------------------------------------------------
   ssize_t ProcessInfo::Read(int fd)
   {
-    assert("ProcessInfo::Read(int fd)" == "Implemented");
+    assert(string("ProcessInfo::Read(int fd)") == "Implemented");
     return(-1);
   }
   
@@ -779,7 +781,7 @@ namespace Dwm {
   //--------------------------------------------------------------------------
   ssize_t ProcessInfo::Write(int fd) const
   {
-    assert("ProcessInfo::Write(int fd)" == "Implemented");
+    assert(string("ProcessInfo::Write(int fd)") == "Implemented");
     return(-1);
   }
   
@@ -788,7 +790,7 @@ namespace Dwm {
   //--------------------------------------------------------------------------
   size_t ProcessInfo::Read(FILE * f)
   {
-    assert("ProcessInfo::Read(FILE * f)" == "Implemented");
+    assert(string("ProcessInfo::Read(FILE * f)") == "Implemented");
     return(0);
   }
   
@@ -797,10 +799,10 @@ namespace Dwm {
   //--------------------------------------------------------------------------
   size_t ProcessInfo::Write(FILE *f) const
   {
-    assert("ProcessInfo::Write(FILE *f)" == "Implemented");
+    assert(string("ProcessInfo::Write(FILE *f)") == "Implemented");
     return(0);
   }
-    
+  
   //--------------------------------------------------------------------------
   //!  
   //--------------------------------------------------------------------------
