@@ -1,6 +1,6 @@
 //===========================================================================
 // @(#) $Name$
-// @(#) $Id: DwmRusage.cc 8388 2016-04-17 03:23:45Z dwm $
+// @(#) $Id: DwmRusage.cc 10621 2020-05-02 21:51:49Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2006-2007
 //  All rights reserved.
@@ -50,7 +50,7 @@
 #include "DwmSysLogger.hh"
 #include "DwmRusage.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.6.13/src/DwmRusage.cc 8388 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.6.16/src/DwmRusage.cc 10621 $");
 
 using namespace std;
 
@@ -560,7 +560,7 @@ namespace Dwm {
   //--------------------------------------------------------------------------
   size_t Rusage::Read(FILE * f)
   {
-    assert("Rusage::Read(FILE *f)" == "Implemented");
+    assert(string("Rusage::Read(FILE *f)") == "Implemented");
     return(0);
   }
   
@@ -569,7 +569,7 @@ namespace Dwm {
   //--------------------------------------------------------------------------
   size_t Rusage::Write(FILE *f) const
   {
-    assert("Rusage::Write(FILE *f)" == "Implemented");
+    assert(string("Rusage::Write(FILE *f)") == "Implemented");
     return(0);
   }
 
