@@ -1,8 +1,8 @@
 //===========================================================================
 // @(#) $Name$
-// @(#) $Id: DwmStringUtils.cc 8388 2016-04-17 03:23:45Z dwm $
+// @(#) $Id: DwmStringUtils.cc 10391 2020-04-10 22:49:22Z dwm $
 //===========================================================================
-//  Copyright (c) Daniel W. McRobb 2005-2007
+//  Copyright (c) Daniel W. McRobb 2005-2007, 2013, 2016, 2019
 //  All rights reserved.
 //
 //  Redistribution and use in source and binary forms, with or without
@@ -42,7 +42,9 @@ extern "C" {
 #include "DwmSvnTag.hh"
 #include "DwmStringUtils.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.6.13/src/DwmStringUtils.cc 8388 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.6.16/src/DwmStringUtils.cc 10391 $");
+
+using namespace std;
 
 namespace Dwm {
 
@@ -51,12 +53,12 @@ namespace Dwm {
     //------------------------------------------------------------------------
     //!  
     //------------------------------------------------------------------------
-    bool HasSuffix(const std::string & str, const std::string & suffix)
+    bool HasSuffix(const string & str, const string & suffix)
     {
       bool  rc = false;
       if (str.length() >= suffix.length()) {
-        std::string::size_type  suffixPos = str.rfind(suffix);
-        if (suffixPos != std::string::npos) {
+        string::size_type  suffixPos = str.rfind(suffix);
+        if (suffixPos != string::npos) {
           if (suffixPos == (str.length() - suffix.length())) {
             rc = true;
           }
@@ -68,33 +70,40 @@ namespace Dwm {
     //------------------------------------------------------------------------
     //!  
     //------------------------------------------------------------------------
-    bool StringToVector(const std::string & s, char sep,
-                        std::vector<std::string> & result)
+    bool StringToVector(const string & s, char sep, vector<string> & result,
+                        bool ignoreEmpty)
     {
       result.clear();
-      std::string::size_type  idx = 0;
-      std::string::size_type  slen = s.length();
-      while (idx < slen) {
-        std::string  tok;
-        std::string::size_type  nextIdx = s.find_first_of(sep, idx);
+      string::size_type  idx = 0;
+      string::size_type  nextIdx;
+      do {
+        nextIdx = s.find_first_of(sep, idx);
         if (nextIdx != s.npos) {
-          tok = s.substr(idx, nextIdx - idx);
-          result.push_back(tok);
+          if (ignoreEmpty) {
+            if (nextIdx > idx) {
+              result.push_back(s.substr(idx, nextIdx - idx));
+            }
+          }
+          else {
+            result.push_back(s.substr(idx, nextIdx - idx));
+          }
           idx = nextIdx + 1;
         }
-        else {
-          tok = s.substr(idx, s.length() - idx);
-          result.push_back(tok);
-          break;
-        }
+      } while (nextIdx != s.npos);
+      
+      if (s.length() > idx) {
+        result.push_back(s.substr(idx, s.length() - idx));
+      }
+      else if ((! ignoreEmpty) && (s.length() == idx)) {
+        result.push_back("");
       }
       return (! result.empty());
     }
-
+    
     //------------------------------------------------------------------------
     //!  
     //------------------------------------------------------------------------
-    bool StringTo(const std::string & s, std::string & target)
+    bool StringTo(const string & s, string & target)
     {
       target = s;
       return(true);
@@ -103,7 +112,7 @@ namespace Dwm {
     //------------------------------------------------------------------------
     //!  
     //------------------------------------------------------------------------
-    bool StringTo(const std::string & s, char & target, int base)
+    bool StringTo(const string & s, char & target, int base)
     {
       return(StringToIntegral<char>(s, target, base));
     }
@@ -111,7 +120,7 @@ namespace Dwm {
     //------------------------------------------------------------------------
     //!  
     //------------------------------------------------------------------------
-    bool StringTo(const std::string & s, signed char & target, int base)
+    bool StringTo(const string & s, signed char & target, int base)
     {
       return(StringToIntegral<signed char>(s, target, base));
     }
@@ -119,7 +128,7 @@ namespace Dwm {
     //------------------------------------------------------------------------
     //!  
     //------------------------------------------------------------------------
-    bool StringTo(const std::string & s, unsigned char & target, int base)
+    bool StringTo(const string & s, unsigned char & target, int base)
     {
       return(StringToIntegral<unsigned char>(s, target, base));
     }
@@ -127,7 +136,7 @@ namespace Dwm {
     //------------------------------------------------------------------------
     //!  
     //------------------------------------------------------------------------
-    bool StringTo(const std::string & s, short & target, int base)
+    bool StringTo(const string & s, short & target, int base)
     {
       return(StringToIntegral<short>(s, target, base));
     }
@@ -135,7 +144,7 @@ namespace Dwm {
     //------------------------------------------------------------------------
     //!  
     //------------------------------------------------------------------------
-    bool StringTo(const std::string & s, unsigned short & target, int base)
+    bool StringTo(const string & s, unsigned short & target, int base)
     {
       return(StringToIntegral<unsigned short>(s, target, base));
     }
@@ -143,7 +152,7 @@ namespace Dwm {
     //------------------------------------------------------------------------
     //!  
     //------------------------------------------------------------------------
-    bool StringTo(const std::string & s, int & target, int base)
+    bool StringTo(const string & s, int & target, int base)
     {
       return(StringToIntegral<int>(s, target, base));
     }
@@ -151,7 +160,7 @@ namespace Dwm {
     //------------------------------------------------------------------------
     //!  
     //------------------------------------------------------------------------
-    bool StringTo(const std::string & s, unsigned int & target, int base)
+    bool StringTo(const string & s, unsigned int & target, int base)
     {
       return(StringToIntegral<unsigned int>(s, target, base));
     }
@@ -159,7 +168,7 @@ namespace Dwm {
     //------------------------------------------------------------------------
     //!  
     //------------------------------------------------------------------------
-    bool StringTo(const std::string & s, long & target, int base)
+    bool StringTo(const string & s, long & target, int base)
     {
       return(StringToIntegral<long>(s, target, base));
     }
@@ -167,7 +176,7 @@ namespace Dwm {
     //------------------------------------------------------------------------
     //!  
     //------------------------------------------------------------------------
-    bool StringTo(const std::string & s, unsigned long & target, int base)
+    bool StringTo(const string & s, unsigned long & target, int base)
     {
       return(StringToIntegral<unsigned long>(s, target, base));
     }
@@ -175,7 +184,7 @@ namespace Dwm {
     //------------------------------------------------------------------------
     //!  
     //------------------------------------------------------------------------
-    bool StringTo(const std::string & s, long long & target, int base)
+    bool StringTo(const string & s, long long & target, int base)
     {
       return(StringToIntegral<long long>(s, target, base));
     }
@@ -183,7 +192,7 @@ namespace Dwm {
     //------------------------------------------------------------------------
     //!  
     //------------------------------------------------------------------------
-    bool StringTo(const std::string & s, unsigned long long & target, int base)
+    bool StringTo(const string & s, unsigned long long & target, int base)
     {
       return(StringToIntegral<unsigned long long>(s, target, base));
     }
@@ -191,7 +200,7 @@ namespace Dwm {
     //------------------------------------------------------------------------
     //!  
     //------------------------------------------------------------------------
-    bool StringTo(const std::string & s, float & target)
+    bool StringTo(const string & s, float & target)
     {
       bool  rc = false;
       if (! s.empty()) {
@@ -203,7 +212,7 @@ namespace Dwm {
           rc = true;
         }
 #else
-		std::istringstream  is;
+		istringstream  is;
 		is.str(s);
 		if (is >> target)
 			rc = true;
@@ -215,7 +224,7 @@ namespace Dwm {
     //------------------------------------------------------------------------
     //!  
     //------------------------------------------------------------------------
-    bool StringTo(const std::string & s, double & target)
+    bool StringTo(const string & s, double & target)
     {
       bool  rc = false;
 
@@ -233,7 +242,7 @@ namespace Dwm {
     //------------------------------------------------------------------------
     //!  
     //------------------------------------------------------------------------
-    bool StringTo(const std::string & s, bool & target)
+    bool StringTo(const string & s, bool & target)
     {
       bool  rc = false;
       
