@@ -1,6 +1,6 @@
 //===========================================================================
 // @(#) $Name$
-// @(#) $Id: DwmUnitAssert.cc 8388 2016-04-17 03:23:45Z dwm $
+// @(#) $Id: DwmUnitAssert.cc 10192 2019-11-24 01:18:34Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2006,2007,2009,2015
 //  All rights reserved.
@@ -45,7 +45,7 @@
 #include "DwmSvnTag.hh"
 #include "DwmUnitAssert.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.6.13/src/DwmUnitAssert.cc 8388 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.6.16/src/DwmUnitAssert.cc 10192 $");
 
 namespace Dwm {
 
@@ -489,5 +489,21 @@ namespace Dwm {
     }
     return(os);
   }
-  
+
+  //--------------------------------------------------------------------------
+  //!  
+  //--------------------------------------------------------------------------
+  int Assertions::PrintAndReturn()
+  {
+    int  rc = 0;
+    if (Total().Failed() > 0) {
+      Print(std::cerr, true);
+      rc = 1;
+    }
+    else {
+      std::cout << Total() << " passed" << std::endl;
+    }
+    return rc;
+  }
+
 }  // namespace Dwm
