@@ -1,6 +1,6 @@
 //===========================================================================
-// @(#) $DwmPath: dwm/libDwm/tags/libDwm-0.6.13/tests/TestDwmDirectoryEntry.cc 8389 $
-// @(#) $Id: TestDwmDirectoryEntry.cc 8389 2016-04-17 04:31:36Z dwm $
+// @(#) $DwmPath: dwm/libDwm/tags/libDwm-0.6.16/tests/TestDwmDirectoryEntry.cc 10621 $
+// @(#) $Id: TestDwmDirectoryEntry.cc 10621 2020-05-02 21:51:49Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2011
 //  All rights reserved.
@@ -49,14 +49,14 @@
 using namespace std;
 using Dwm::DirectoryEntry;
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.6.13/tests/TestDwmDirectoryEntry.cc 8389 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.6.16/tests/TestDwmDirectoryEntry.cc 10621 $");
 
-typedef struct {
+struct TestPathResult {
   string  orig;
   string  path;
   string  name;
   string  extension;
-} TestPathResult;
+};
 
 //----------------------------------------------------------------------------
 //!  
