@@ -1,6 +1,6 @@
 //===========================================================================
-// @(#) $DwmPath: dwm/libDwm/tags/libDwm-0.6.13/tests/TestThreadQueue.cc 8389 $
-// @(#) $Id: TestThreadQueue.cc 8389 2016-04-17 04:31:36Z dwm $
+// @(#) $DwmPath: dwm/libDwm/tags/libDwm-0.6.16/tests/TestThreadQueue.cc 10193 $
+// @(#) $Id: TestThreadQueue.cc 10193 2019-11-24 01:19:18Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2016
 //  All rights reserved.
@@ -53,7 +53,7 @@ extern "C" {
 #include "DwmUnitAssert.hh"
 #include "DwmThreadQueue.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.6.13/tests/TestThreadQueue.cc 8389 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.6.16/tests/TestThreadQueue.cc 10193 $");
 
 using namespace std;
 using namespace Dwm;
@@ -195,7 +195,6 @@ void SimplePopFn(Thread::Queue<uint64_t> * queue, const string & name)
       ++processed;
     }
   }
-  syslog(LOG_INFO, "%s processed %lu", name.c_str(), processed);
   return;
 }
 
@@ -224,7 +223,6 @@ void BulkPopFn(Thread::Queue<uint64_t> * queue, const string & name)
   while (processed < 1000000) {
     processed += queue->Swap(entries);
   }
-  syslog(LOG_INFO, "%s processed %lu", name.c_str(), processed);
   return;
 }
 
@@ -332,14 +330,6 @@ int main(int argc, char *argv[])
     TestSimplePerformance();
     TestBulkPerformance();
   }
-  
-  if (Dwm::Assertions::Total().Failed() > 0) {
-    Dwm::Assertions::Print(std::cerr, true);
-    return(1);
-  }
-  else {
-    std::cout << Dwm::Assertions::Total() << " passed" << std::endl;
-  }
-  
-  return(0);
+
+  return Assertions::PrintAndReturn();
 }
